@@ -11,6 +11,9 @@ class hubspot:
   from . import companies
   from . import contacts
   from . import deals
+  from . import owners
+  from . import products
+  from . import lineitems
 
   def __init__(self, client_id, client_secret, refresh_token):
     self.refresh_token = refresh_token
