@@ -13,6 +13,7 @@ class zoho:
   from . import customerpayments
   from . import users
   from . import items
+  from . import expenses
 
   def __init__(self, app, client_id, client_secret, refresh_token, organization):
     self.refresh_token = refresh_token
@@ -25,6 +26,8 @@ class zoho:
     }
     result = post(post_url, AUTH_HEADERS, auth_body)
     auth_result = result['content']
+    if 'access_token' not in auth_result.keys():
+      raise Exception(f"Access token not returned: {result}")
     HEADERS['Authorization'] = f"Bearer {auth_result['access_token']}"
 
   # Contains utilities for interacting with the Zoho API
